const multer = require("multer");
const mkdirp = require("mkdirp");

const academicStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/academic";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;
    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});
const imageStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/images";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;
    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});
const forumImageStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/forum";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + req.user.id + "." + extention.toLocaleLowerCase());
  },
});

const slideStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/slide";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});

const userStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/user";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});

const questionStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/question";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});


const question2Storage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/question2";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});

const podcastStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    let dir = "../files.gi-board.ir/upload/podcast";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});
const memeberStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    
    let dir =  "../files.gi-board.ir/upload/member"; 
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});



const pageStorage = multer.diskStorage({
  destination: function (req, file, cb) {
    console.log("satte pageStorage");
    let dir = "../files.gi-board.ir/upload/pagefiles";
    let newdir = mkdirp.sync(dir);
    if (!newdir) newdir = dir;

    cb(null, newdir);
  },
  filename: function (req, file, cb) {
    let extention = file.originalname.slice(
      (Math.max(0, file.originalname.lastIndexOf(".")) || Infinity) + 1
    );
    cb(null, Date.now() + "." + extention.toLocaleLowerCase());
  },
});

const uploadImage = multer({
  storage: imageStorage,
});
const uploadForumImage = multer({
  storage: forumImageStorage,
});

const uploadAcademic = multer({
  storage: academicStorage,
});

const uploadSlide = multer({
  storage: slideStorage,
});

const uploadUserPicture = multer({
  storage: userStorage,
});

const uploadQuestion = multer({
  storage: questionStorage,
});

const uploadQuestion2= multer({
  storage: question2Storage,
});

const uploadPodcast = multer({
  storage: podcastStorage,
});
const uploadMember = multer({
  storage: memeberStorage,
});
const uploadPage = multer({
  storage: pageStorage,
});

module.exports = {
  uploadImage,
  uploadForumImage,
  uploadAcademic,
  uploadSlide,
  uploadPodcast,
  uploadMember,
  uploadPage,
  uploadQuestion,
  uploadQuestion2,
  uploadUserPicture,
};
