import Link from "next/link";
import axios from "axios";
import { useEffect, useState } from "react";
import Paper from "@mui/material/Paper";
import Table from "@mui/material/Table";
import { Grid, TableHead, colors } from "@mui/material";
import TableRow from "@mui/material/TableRow";
import TableBody from "@mui/material/TableBody";
import TableCell from "@mui/material/TableCell";
import TableContainer from "@mui/material/TableContainer";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import DeleteIcon from "@mui/icons-material/Delete";

import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  deleteAlert,
  successDeleteMessage,
} from "../../utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";

export default function DisplayMessage(props) {
  const [controller, dispatch] = useLiTechController();
  const [messages, setMessages] = useState();
  const [open, setOpen] = useState(false);
  const [showMessage, setShowMessage] = useState([]);

  const handleOpen = () => setOpen(true);
  const handleClose = () => {
    setOpen(false);
  };

  const getMessages = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/contact/get`).then((result) => {
        setLoading(dispatch, false);
        setMessages(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const messageReaded = async (id) => {
    console.log("idddddddd", id);
    try {
      await axios
        .post(`/api/contact/read`, { id })

        .then((result) => {
          console.log("result", result);
          getMessages();
        })
        .catch((err) => {
          console.log(err);
        });
    } catch (err) {
      console.log(err);
    }
  };

  const deleteMessage = async (id) => {
    console.log("idid", id);
    try {
      if (await deleteAlert()) {
        await axios
          .post(`/api/contact/delete`, { id })

          .then((result) => {
            console.log("result", result);

            successDeleteMessage();

            getMessages();
          })
          .catch((err) => {
            console.log(err);
          });
      }
    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    if (controller.authenticated ) {
      getMessages();
    }
  }, [controller.authenticated]);

  return (
    <main>
      <section className="contact__area grey-bg-13 pb-120 pt-150">
        <div className="container">
          <div className="row">
            <div className="col-xxl-12 col-xlg-12- col-lg-12">
              <TableContainer component={Paper}>
                <Table
                  size="large"
                  sx={{ minWidth: 650 }}
                  aria-label="simple table"
                >
                  <TableHead style={{ textAlign: "center" }}>
                    <TableRow>
                      <TableCell>نام و نام خانوادگی</TableCell>
                      <TableCell>پست الکترونیک</TableCell>
                      <TableCell>شماره تماس</TableCell>
                      <TableCell style={{ width: 130 }}>مشاهده پیام</TableCell>
                      <TableCell style={{ width: 90 }}>حذف پیام</TableCell>
                    </TableRow>
                  </TableHead>
                  <TableBody>
                    {messages?.map((row) => (
                      <TableRow
                        style={{
                          backgroundColor: row.isReaded ? "#fefefe" : "#f0f0f0",
                        }}
                        key={row.name}
                      >
                        <TableCell>{row.name}</TableCell>
                        <TableCell>{row.email}</TableCell>
                        <TableCell>{row.phone}</TableCell>

                        <TableCell>
                          <button
                            type="button"
                            style={{
                              backgroundColor: "#0d6efd",
                              padding: 8,
                              borderRadius: 5,
                              color: "#fff",
                              fontFamily: "inherit",
                            }}
                            onClick={() => {
                              setShowMessage([
                                `نام : ${row.name}`,
                                `ایمیل : ${row.email}`,
                                `شماره تماس : ${row.phone}`,
                                `متن پیام : ${row.message}`,
                              ]);
                              handleOpen();
                              messageReaded(row._id);
                            }}
                          >
                            نمایش پیام
                          </button>
                        </TableCell>
                        <TableCell align="center">
                          <DeleteIcon
                            className="button"
                            onClick={() => {
                              deleteMessage(row._id);
                            }}
                          />
                        </TableCell>
                      </TableRow>
                    ))}
                  </TableBody>
                </Table>
              </TableContainer>
            </div>
          </div>{" "}
        </div>
      </section>
      <Dialog
         open={open}
         onClose={handleClose}
         aria-labelledby="alert-dialog-title"
         aria-describedby="alert-dialog-description"
       >
         <IconButton color="inherit" onClick={handleClose} aria-label="close">
           <CloseIcon />
         </IconButton>

         <DialogContent style={{ minWidth: 500, minHeight: 250 }}>
           {showMessage?.map((item) => (
             <Grid container>
               <Grid item>
                  <div
                   dangerouslySetInnerHTML={{
                     __html: item.replace(/\n/g, "c"),
                   }}
                 /> 
               </Grid>
             </Grid>
           ))}
         </DialogContent>
       </Dialog>
    </main>
  );
}
