import Image from "next/image";
import Link from "next/link";
import axios from "axios";
import { useEffect, useState } from "react";
import { setLoading, useLiTechController } from "@/utils/context";
import EditComponent from "@/components/editComponent";
import DisplayComponent from "@/components/displayComponent";

export default function Home(props) {
  const [controller, dispatch] = useLiTechController();
  const [result, setResult] = useState();

  const [data, setData] = useState();

  const [pageItem, setPageItem] = useState();

  const getMembers = () => {
    setLoading(dispatch, true);
    axios
      .get("/api/member/2")
      .then((result) => {
        setLoading(dispatch, false);
        setResult(result.data.data);
      })
      .catch((err) => {
        console.log("err", err);
      });
  };

  const getPageData = async () => {
    try {
      await axios.get(`/api/page/get`).then((result) => {
        console.log("result", result);
        console.log("result.data?.data", result.data?.data);
        setData(result.data?.data);

        setPageItem(
          controller.authenticated && controller.userRole === "admin" && (
            <EditComponent
              titleProp={result.data?.data?.[0].title}
              textProp={result.data?.data?.[0].text}
              pageName="home"
              getPageData={getPageData}
            />
          )
        );
      });
    } catch (err) {
      console.log(err);
    }
  };

  useEffect(() => {
    getPageData();
    getMembers();
  }, [controller.authenticated]);

  return (
    <div>
      {controller.loading && (
        <div id="loading">
          <div id="loading-center">
            <div id="loading-center-absolute">
              <div className="object" id="object_one"></div>
              <div className="object" id="object_two"></div>
              <div className="object" id="object_three"></div>
              <div className="object" id="object_four"></div>
              <div className="object" id="object_five"></div>
            </div>
          </div>
        </div>
      )}
      <main>
        <section className="slider__area p-relative">
          <div className="slider__wrapper-7">
            <div
              className="slider__item-7 slider__height slider__height-7 d-flex align-items-center"
              data-background="/slider-1.jpg"
            >
              <div className="container slider__height-7 imageback">
                <div className="row">
                  <div className="col-12 center">
                    <div className="slider__content-7 mt-10 p-relative">
                      <h3 className="slider__title-7">
                        هیات بورد فوق تخصصی بیماری های گوارش و کبد بزرگسالان
                      </h3>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>

        <section className="features__area features__mt--95 z-index-1 p-relative">
          <div className="container">
            <div className="row row-cols-xxl-5 row-cols-xl-5 row-cols-lg-3 row-cols-md-2 row-cols-1 justify-content-center">
              <div className="col">
                <div className="features__item-7 text-center blue-bg mb-30 transition-3">
                  <div className="features__icon-7 mb-30">
                    <i className="flaticon-video-tutorial"></i>
                  </div>
                  <div className="features__content-7">
                    <h3 className="features__title-7">
                      <Link href="/page/examsource">
                        منابع آزمون دانشنامه سال جاری
                      </Link>
                    </h3>
                  </div>
                </div>
              </div>
              <div className="col">
                <div className="features__item-7 text-center yellow-bg mb-30 transition-3">
                  <div className="features__icon-7 mb-30">
                    <i className="flaticon-high-five"></i>
                  </div>
                  <div className="features__content-7">
                    <h3 className="features__title-7">
                      <Link href="/page/assistantplan">
                        برنامه دوره دستیاری تخصصی
                      </Link>
                    </h3>
                  </div>
                </div>
              </div>
              <div className="col">
                <div className="features__item-7 text-center pink-bg mb-30 transition-3">
                  <div className="features__icon-7 mb-30">
                    <i className="flaticon-teacher-1"></i>
                  </div>
                  <div className="features__content-7">
                    <h3 className="features__title-7">
                      <Link href="/page/educationcenter">
                        مراکز تربیت دستیار فوق تخصص
                      </Link>
                    </h3>
                  </div>
                </div>
              </div>
              <div className="col">
                <div className="features__item-7 text-center green-bg mb-30 transition-3">
                  <div className="features__icon-7 mb-30">
                    <i className="flaticon-online-course-1"></i>
                  </div>
                  <div className="features__content-7">
                    <h3 className="features__title-7">
                      <Link href="/questionsexample">
                        نمونه سوالات آزمون دانشنامه
                      </Link>
                    </h3>
                  </div>
                </div>
              </div>
              <div className="col">
                <div className="features__item-7 text-center purple-bg mb-30 transition-3">
                  <div className="features__icon-7 mb-30">
                    <i className="flaticon-writing"></i>
                  </div>
                  <div className="features__content-7">
                    <h3 className="features__title-7">
                      <Link href="/questionsexample2">
                        نمونه سوالات پذیرش دستیار متخصص
                      </Link>
                    </h3>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>

        <section className="about__area pt-90">
          <div className="container">
            <div className="row">
              <DisplayComponent />
              {pageItem}
            </div>
          </div>
        </section>

        <section className="category__area grey-bg-5 pt-110 pb-120">
          <div className="container">
            <div className="row justify-content-center">
              <div className="col-xxl-4 col-xl-6">
                <div className="section__title-wrapper-7 mb-50 text-center">
                  <h2 className="section__title-7">
                    معرفی اعضای هیات ممتحنه فعلی
                  </h2>
                </div>
              </div>
            </div>
            <div className="row">
              {result?.map((item) => (
                <div
                  className="col-xxl-4 col-xl-4 col-lg-4 col-md-6"
                  key={item._id}
                >
                  <div className="category__item white-bg transition-3 mb-30 d-flex align-items-center">
                    <div
                      className="category__icon mr-20"
                      style={{ minHeight: 130 }}
                    >
                      <Image
                        width={100}
                        height={100}
                        alt="هیات بورد فوق تخصصی بیماری های گوارش و کبد بزرگسالان"
                        src={`https://files.gi-board.ir/upload/member/${item.fileName}`}
                      />
                    </div>
                    <div
                      className="category__content"
                      style={{
                        display: "inline-block",
                        maxHeight: 30,
                        overflow: "hidden",
                      }}
                    >
                      <h3 className="category__title">
                        <span>{item.name}</span>
                      </h3>
                      <span>{item.education}</span>
                      <div>
                        <span>{item.description}</span>
                      </div>
                    </div>
                  </div>
                </div>
              ))}
            </div>
          </div>
        </section>
      </main>
    </div>
  );
}
