
import axios from "axios";
import { useEffect, useState } from "react";
import {
  successMessage,
  errorMessage,
  dataErrorsMessage,
  catchMessage,
  successStoreMessage,
  successUpdateMessage,
} from "../../utiliz/showMessage";
import { setLoading, useLiTechController } from "@/utils/context";

const Joi = require("joi");
Joi.objectId = require("joi-objectid")(Joi);

export default function Members(props) {
  const [controller, dispatch] = useLiTechController();

  const [name, setName] = useState("");
  const [rowNumber, setRowNumber] = useState(0);
  const [description, setDiscription] = useState("");
  const [fileName, setFileName] = useState();
  const [education, setEducation] = useState();
  const { id, mode, handleClose, getMembers, defaultRownumber } = props;

  const clearForm = () => {
    try {
      setName("");
      setRowNumber(0);
      setDiscription("");
      setFileName();
    } catch (error) {
      throw error;
    }
  };

  const fileChangeHandler = (e) => {
    setFileName(e.target.files[0]);
  };

  const validateFields = () => {
    try {
      const schema = Joi.object({
        name: Joi.string().required().min(3).max(256).messages({
          "string.min": `نام حداقل {#limit} حرف وارد شود  `,
          "string.max": `نام حداکثر {#limit} حرف وارد شود  `,
          "any.required": ` نام وارد شود`,
          "string.empty": ` نام وارد شود`,
        }),

        education: Joi.string().required().min(3).max(256).messages({
          "string.min": `عنوان حداقل {#limit} حرف وارد شود  `,
          "string.max": `عنوان حداکثر {#limit} حرف وارد شود  `,
          "any.required": ` عنوان وارد شود`,
          "string.empty": ` عنوان وارد شود`,
        }),

        description: Joi.string().required().messages({
          "any.required": `  توضیحات وارد شود`,
          "string.empty": ` توضیحات وارد شود`,
        }),
      });
      const { error } = schema.validate({
        name: name,
        education : education,
        description: description,
      });
      if (error) {
        errorMessage(error.details[0].message);
        return false;
      }
      if (!fileName) {
        errorMessage("لطفا فایل مورد نظر خود را انتخاب کنید");
        return false;
      }
      return true;
    } catch (error) {
      console.log("------------", error);

      setLoading(false);
      catchMessage(error);
      return false;
    }
  };
  const handleSubmitClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("name", name);
      formData.append("fileName", fileName);
      formData.append("description", description);
      formData.append("rowNumber", rowNumber);
      formData.append("mode", mode);
      formData.append("education", education);
     
      setLoading(dispatch, true);
      await axios
        .post("/api/member/store/", formData, {
          headers: {
            "Content-Type": "multipart/formdata",
          },
        })

        .then((result) => {
          setLoading(dispatch, false);

          console.log("result", result);
          setLoading(dispatch, false);
          clearForm();
          getMembers();
          handleClose();
          successStoreMessage();
        })
        .catch((err) => {
          setLoading(dispatch, false);
          console.log(err);
        });
    } catch (error) {
      setLoading(dispatch, false);
      console.log(error);
    }
  };

  const getMember = () => {
    try {
      axios.post(`/api/member/getmember`, { id }).then((result) => {
        console.log("resultresultresult", result.data.data);
        setName(result.data.data.name);
        setRowNumber(result.data.data.rowNumber);
        setDiscription(result.data.data.description);
        setFileName(result.data.data.fileName);
        setEducation(result.data.data.education);
      });
    } catch (err) {
      console.log(err);
    }
  };

  const handleEditClick = async () => {
    try {
      let validationResult = await validateFields();
      if (!validationResult) {
        return;
      }
      const formData = new FormData();
      formData.append("id", id);
      formData.append("name", name);
      formData.append("fileName", fileName);
      formData.append("description", description);
      formData.append("rowNumber", rowNumber);
      formData.append("mode", mode);
      formData.append("education", education);
      setLoading(dispatch, true);
      console.log("updatedata", formData);
      axios
        .put("/api/member/update", formData)
        .then((result) => {
          setLoading(dispatch, false);
          clearForm();
          successUpdateMessage();
          handleClose();
          getMembers();
        })
        .catch((err) => {
          console.log("errerrerr", err);
          errorMessage(err.message);
        });
    } catch (err) {
      console.log(err);
    }
  };
  useEffect(() => {
    if (id) {
      getMember();
    } else {
      setRowNumber(defaultRownumber + 1);
    }
  }, []);
  return (
    <div className="row">
      <div className="col-xxl-12 col-xl-12 col-lg-12">
        <div className="contact__form contact__form-2 white-bg">
          <form>
            <div className="row">
              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className=" contact__input contact__input-2 mb-30">
                  <label>ردیف{mode}</label>
                  <input
                    name="rowNumber"
                    id="rowNumber"
                    type="number"
                    value={`${rowNumber}`}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setRowNumber(e.target.value);
                    }}
                  />
                </div>
              </div>
              <div className="col-xxl-6 col-xl-6 col-lg-6 col-md-6">
                <div className="contact__input contact__input-2 mb-30">
                  <label>نام</label>
                  <input
                    name="name"
                    id="name"
                    type="text"
                    value={name}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setName(e.target.value);
                    }}
                  />
                </div>
              </div>
              <div className="col-12">
                <div className="contact__input contact__input-2 mb-30">
                  <label>عنوان</label>
                  <input
                    name="education"
                    id="education"
                    type="text"
                    value={education}
                    onChange={(e) => {
                      console.log(e.target.value);
                      setEducation(e.target.value);
                    }}
                  />
                </div>
              </div>

              <div className=" col-md-12">
                <div className=" contact__input contact__input-2 mb-30 ">
                  <label>برای اپلود تصویر خود اینجا کلیک کنید</label>
                  <input
                    name="file"
                    id="file"
                    type="file"
                    accept="image/png, image/gif, image/jpeg"
                    onChange={fileChangeHandler}
                  />
                </div>
              </div>

              <div className=" col-md-12">
                <div className="contact__input contact__input-2 mb-30">
                  <label>توضیحات کوتاه</label>
                  <textarea
                    id="description"
                    name="description"
                    rows="4"
                    cols="50"
                    value={description}
                    onChange={(e) => {
                      setDiscription(e.target.value);
                    }}
                  />
                </div>
              </div>

              <div className="col-xl-12">
                <div className="contact__form-btn-2">
                  <button
                    style={{ float: "left" }}
                    type="button"
                    onClick={() => {
                      id ? handleEditClick() : handleSubmitClick();
                    }}
                  >
                    {id ? "ویرایش" : "ثبت"}
                  </button>
                </div>
              </div>
            </div>
          </form>
        </div>
      </div>
    </div>
  );
}
