import Navbar from "@/components/navbar";
import Link from "next/link";
import { useEffect, useState } from "react";
import axios from "axios";
import AddIcon from "@mui/icons-material/Add";
import EditIcon from "@mui/icons-material/Edit";
import Dialog from "@mui/material/Dialog";
import DialogContent from "@mui/material/DialogContent";
import DialogTitle from "@mui/material/DialogTitle";
import {
  useLiTechController,
  setLoading,
  setStartLogin,
} from "@/utils/context";
import HelpOutlineIcon from "@mui/icons-material/HelpOutline";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import DeleteIcon from "@mui/icons-material/Delete";
import Questions2 from "./questions2";

import {
  successStoreMessage,
  errorMessage,
  catchMessage,
  deleteAlert,
  successDeleteMessage,
  loginAlert,
  activeLogin,
} from "../../utiliz/showMessage";
import config from "@/utils/config";
import LoginComponent from "@/components/login";

export default function QuestionExample(props) {
  const [controller, dispatch] = useLiTechController();
  const [categories, setCategories] = useState();
  const [open, setOpen] = useState(false);
  const [show, setShow] = useState(false);
  const [openLogin, setOpenLogin] = useState(false);
  const handleShow = () => setShow(true);
  const handleOpen = () => setOpen(true);

  const handleClose = () => {
    setEditId();
    setOpen(false);
    setShow(false);
    setOpenLogin(false);
  };

  const [questions, setQuestions] = useState();
  const [editId, setEditId] = useState();
  const [showDes, setShowDes] = useState("");
  const [addNewItem, setAddNewItem] = useState();
  const [datas, setDatas] = useState(questions);

  const handleOpenLogin = () => setOpenLogin(true);
  const handleCloseLogin = () => {
    setOpenLogin(false);
  };

  const getQuestions = async () => {
    try {
      setLoading(dispatch, true);
      await axios.get(`/api/question2/question`).then((result) => {
        setLoading(dispatch, false);
        setQuestions(result.data.data);
        setDatas(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const login = async (id) => {
    console.log("idid", id);
    try {
      if(!controller.authenticated){
        if (await loginAlert()) {
       handleOpenLogin();
     }
     }else if(controller.active !== true){
       activeLogin();
     }

     setStartLogin(dispatch, false);
    } catch (err) {
      console.log(err);
    }
  };

  const getQuestionCategories = async () => {
    try {
      await axios.get(`/api/question2/questioncategories`).then((result) => {
        setCategories(result.data.data);
      });
    } catch (err) {
      errorMessage("Error in proccess");
    }
  };

  const deleteMessage = async (id) => {
    console.log("idid", id);
    try {
      if (await deleteAlert()) {
        await axios
          .post(`/api/question2/delete`, { id })

          .then((result) => {
            console.log("result", result);

            successDeleteMessage();

            getQuestions();
            getQuestionCategories();
          })
          .catch((err) => {
            console.log(err);
          });
      }
    } catch (err) {
      console.log(err);
    }
  };

  const handleTabClick = async (category) => {
    if (category == "همه") {
      setDatas(questions);
    } else {
      let temp = await questions.filter((item) => item.category === category);

      setDatas(temp);
    }
  };

  useEffect(() => {
    setAddNewItem(
      controller.authenticated && controller.userRole === "admin" && (
        <AddIcon
          style={{ cursor: "pointer", fontSize: 50 }}
          onClick={handleOpen}
        />
      )
    );

    getQuestions();
    getQuestionCategories();
  }, [controller.authenticated]);

  return (
    <div style={{ overflow: "hidden" }}>
      <Navbar />

      <main>
        <section
          className="page__title-area pt-145 pb-150 p-relative page__title-overlay sliderback"
          data-background="public/img/page-title/page-title-1.jpg"
        >
          <div className="container">
            <div className="row">
              <div className="col-xxl-12">
                <div className="page__title-wrapper">
                  <h3 className="page__title">
                    نمونه سوالات پذیرش دستیار فوق تخصص
                  </h3>
                  <nav aria-label="breadcrumb">
                    <ol className="breadcrumb">
                      <li className="breadcrumb-item">
                        <Link href="/"> خانه </Link>
                      </li>
                      <li
                        className="breadcrumb-item active"
                        aria-current="page"
                      >
                        نمونه سوالات پذیرش دستیار فوق تخصص
                      </li>
                    </ol>
                  </nav>
                </div>
              </div>
            </div>
          </div>
        </section>

        <section className="about__area  about-orange-color">
          <div className="row">
            <section className="category__area grey-bg-5 pt-110 pb-120">
              <div className="container">
                <div className="row justify-content-center">
                  <div className="col-xxl-4 col-xl-6">
                    <div className="section__title-wrapper-7 mb-50 text-center">
                      <h2 className="section__title-7">
                        نمونه سوالات پذیرش دستیار فوق تخصص
                      </h2>
                      {addNewItem}
                    </div>
                  </div>
                </div>
                <div className="row">
                  <div class="col-xxl-7 col-xl-6 col-lg-7">
                    <div class="course__tab mb-55">
                      <ul
                        className="nav nav-tabs justify-content-lg-end"
                        id="myTab"
                        role="tablist"
                      >
                        <div className="col-xxl-7 col-xl-6 col-lg-7">
                          <div className="course__tab mb-55">
                            <ul
                              className="nav nav-tabs justify-content-lg-end"
                              id="myTab"
                              role="tablist"
                            >
                              {categories && categories.length > 0 && (
                                <li class="nav-item" role="presentation">
                                  <button
                                    onClick={() => {
                                      handleTabClick("همه");
                                    }}
                                    class="nav-link active"
                                    id="all-tab"
                                    data-bs-toggle="tab"
                                    data-bs-target="#all"
                                    type="button"
                                    role="tab"
                                    aria-controls="all"
                                    aria-selected="true"
                                  >
                                    همه
                                  </button>
                                </li>
                              )}

                              {categories?.map((item) => (
                                <>
                                  <li className="nav-item" role="presentation">
                                    <button
                                      onClick={() => {
                                        handleTabClick(item);
                                      }}
                                      className="nav-link active"
                                      id="all-tab"
                                      data-bs-toggle="tab"
                                      data-bs-target="#all"
                                      type="button"
                                      role="tab"
                                      aria-controls="all"
                                      aria-selected="true"
                                    >
                                      {item}
                                    </button>
                                  </li>
                                </>
                              ))}
                            </ul>
                          </div>
                        </div>
                      </ul>
                    </div>
                  </div>

                  {datas?.map((item) => (
                    <div>
                      <HelpOutlineIcon
                        style={{
                          cursor: "pointer",
                          fontSize: 30,
                          display: "flex",
                          float: "left",
                          marginRight: -55,
                        }}
                        onClick={() => {
                          setShowDes(item.description);
                          handleShow();
                        }}
                      />
                      {controller.authenticated &&
                        controller.userRole === "admin" && (
                          <>
                            <EditIcon
                              style={{
                                cursor: "pointer",
                                fontSize: 25,
                                display: "flex",
                                float: "right",
                                marginLeft: -55,
                              }}
                              onClick={() => {
                                setEditId(item._id);
                                handleOpen();
                              }}
                            />
                            <DeleteIcon
                              style={{
                                cursor: "pointer",
                                fontSize: 25,
                                display: "flex",
                                float: "left",
                                marginRight: -55,
                                marginLeft: 30,
                              }}
                              className="button"
                              onClick={() => {
                                deleteMessage(item._id);
                              }}
                            />
                          </>
                        )}
                      <div className="category__item white-bg transition-3 mb-30 d-flex align-items-center">
                        <div className="category__icon mr-20">
                          <i className="flaticon-improvement"></i>
                        </div>
                        <div className="category__content">
                          <h3
                            style={{ fontWeight: 50, marginBottom: 10 }}
                            className="category__title"
                          >
                            {item.category}
                          </h3>

                          <h3 className="category__title">{item.title}</h3>
                        </div>
                      </div>
                      <div className="row">
                        <div
                          className="col-12"
                          style={{
                            textAlign: "left",
                            color: "#000",
                            marginTop: -80,
                            marginRight: -30,
                          }}
                        >
                          {(controller.authenticated && controller.active === true)? (
                            <Link
                              href={`${config.uploadAddress}/upload/question2/${item.fileName}`}
                              target={"_blank"}
                            >
                              دانلود فایل
                            </Link>
                          ) : (
                            <button
                              onClick={() => {
                                login();
                              }}
                            >
                              دانلود فایل
                            </button>
                          )}
                        </div>
                      </div>
                    </div>
                  ))}
                </div>
              </div>
            </section>
          </div>
        </section>
        <Dialog
          open={open}
          onClose={handleClose}
          aria-labelledby="alert-dialog-title"
          aria-describedby="alert-dialog-description"
        >
          <DialogTitle id="alert-dialog-title">
            <h3 className="contact-form-title">
              {editId
                ? "ویرایش  سوالات پذیرش دستیار فوق تخصص"
                : " ثبت سوالات پذیرش دستیار فوق تخصص "}
            </h3>
          </DialogTitle>

          <DialogContent>
            <Questions2
              id={editId}
              handleClose={handleClose}
              getQuestions={getQuestions}
              getQuestionCategorie={getQuestionCategories}
              rowDefaultNumber={questions?.length}
            />
          </DialogContent>
        </Dialog>

        <Dialog
          open={show}
          onClose={handleClose}
          aria-describedby="alert-dialog-slide-description"
        >
          <IconButton
            edge="start"
            color="inherit"
            onClick={handleClose}
            aria-label="close"
          >
            <CloseIcon />
          </IconButton>

          <DialogContent style={{ minWidth: 500, minHeight: 350 }}>
            <div
              dangerouslySetInnerHTML={{
                __html: showDes?.replace(/\n/g, "<br/>"),
              }}
            />
          </DialogContent>
        </Dialog>

        <Dialog
          open={openLogin}
          onClose={() => {
            setStartLogin(dispatch, false);
          }}
          aria-labelledby="alert-dialog-title"
          aria-describedby="alert-dialog-description"
        >
          <IconButton color="inherit" onClick={handleClose} aria-label="close">
            <CloseIcon />
          </IconButton>
          <DialogTitle id="alert-dialog-title">
            <h3 className="contact-form-title">ورود به حساب کاربری</h3>
          </DialogTitle>
          <DialogContent>
            <LoginComponent handleCloseLogin={handleCloseLogin} />
          </DialogContent>
        </Dialog>
      </main>
    </div>
  );
}
