import { createContext, useContext, useReducer, useMemo } from "react";
import Cookies from "js-cookie";
// prop-types is a library for typechecking of props
import PropTypes from "prop-types";

// LiTech React main context
const LiTech = createContext();

// Setting custom name for the context which is visible on react dev tools
LiTech.displayName = "Li-tech";

// LiTech React reducer
function reducer(state, action) {
  try {
    switch (action.type) {
      case "LOADING": {
        return { ...state, loading: action.value };
      }
      case "SHOWMENU": {
        return { ...state, show: action.value };
      }
      case "START-LOGIN": {
        return { ...state, startLogin: action.value };
      }

      case "login": {
        console.log("-----", action);
        const newData = {
          ...state,
          startLogin: false,
          show:"",
          authenticated: true,
          userRole : action.value.userRole,
          token: action.value.token,
          active : action.value.active,
        };
        Cookies.set("@setting", JSON.stringify(newData));
        return newData;
      }

      case "logout": {
        const newData = {
          authenticated: false,
          loading: false,
          token: "",
          userRole :"",
          active : false,
          startLogin: false,
          show:"",
        };
        Cookies.set("@setting", JSON.stringify(newData));
        return newData;
      }
      default: {
        throw new Error(`Unhandled action type: ${action.type}`);
      }
    }
  } catch (err) {
    console.log(err);
    return state;
  }
}
let initialState = Cookies.get("@setting");

if (!initialState) {
  initialState = {
    authenticated: false,
    loading: false,
    startLogin: false,
    show:"",
    token: "",
    userRole :"",
    active : false,
  };
  Cookies.set("@setting", JSON.stringify(initialState));
} else {
  initialState = JSON.parse(initialState);
}

// LiTech React context provider
function LiTechControllerProvider({ children }) {
  
  const [controller, dispatch] = useReducer(reducer, initialState);

  const value = useMemo(() => [controller, dispatch], [controller, dispatch]);

  return <LiTech.Provider value={value}>{children}</LiTech.Provider>;
}

// LiTech React custom hook for using context
function useLiTechController() {
  const context = useContext(LiTech);
  if (!context) {
    throw new Error(
      "use Controller should be used inside the  ControllerProvider."
    );
  }
  return context;
}
// Typechecking props for the  ControllerProvider
LiTechControllerProvider.propTypes = {
  children: PropTypes.node.isRequired,
};

// Context module functions
const setLoading = (dispatch, value) => dispatch({ type: "LOADING", value });
const setLogin = (dispatch, value) => dispatch({ type: "login", value });
const setLogout = (dispatch, value) => dispatch({ type: "logout", value });
const setShowMenu = (dispatch, value) => dispatch({ type: "SHOWMENU", value });

const setStartLogin = (dispatch, value) =>
  dispatch({ type: "START-LOGIN", value });

export {
  LiTechControllerProvider,
  useLiTechController,
  setLoading,
  setLogin,
  setLogout,
  setStartLogin,
  setShowMenu,
};
